@@ -12,7 +12,7 @@ PLUGIN(NAME("intel", "Intel vendor specific extensions"),
 		ENTRY("smart-log-add", "Retrieve Intel SMART Log, show it", get_additional_smart_log)
 		ENTRY("market-name", "Retrieve Intel Marketing Name log, show it", get_market_log)
 		ENTRY("temp-stats", "Retrieve Intel Temperature Statistics log, show it", get_temp_stats_log)
-		ENTRY("lat-stats", "Retrieve Intel IO Latancy Statistics log, show it", get_lat_stats_log)
+		ENTRY("lat-stats", "Retrieve Intel IO Latency Statistics log, show it", get_lat_stats_log)
 		ENTRY("internal-log", "Retrieve Intel internal firmware log, save it", get_internal_log)
 	)
 );
